summaryrefslogtreecommitdiffstats
path: root/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py
diff options
context:
space:
mode:
Diffstat (limited to 'testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py')
-rwxr-xr-xtesting/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py
index f7288c510b..4749085962 100755
--- a/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py
+++ b/testing/web-platform/tests/tools/third_party/pywebsocket3/test/test_memorizingfile.py
@@ -31,12 +31,13 @@
"""Tests for memorizingfile module."""
from __future__ import absolute_import
+
import unittest
-import six
-import set_sys_path # Update sys.path to locate mod_pywebsocket module.
+import six
-from mod_pywebsocket import memorizingfile
+import set_sys_path # Update sys.path to locate pywebsocket3 module.
+from pywebsocket3 import memorizingfile
class UtilTest(unittest.TestCase):